@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2023 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -40,7 +40,12 @@ class BaseTearsheet(object):
         (i.e. strategies or securities). Too many plots may cause slow
         rendering. Default 25.
     """
-    def __init__(self, pdf_filename=None, figsize=None, max_cols_for_details=25):
+    def __init__(
+        self,
+        pdf_filename: str = None,
+        figsize: tuple[int, int] = None,
+        max_cols_for_details: int = 25
+        ):
         self.figsize = figsize or (16.0, 12.0) # width, height in inches
         plt.rc("axes", axisbelow=True)
         if pdf_filename:
@@ -147,7 +152,7 @@ class BaseTearsheet(object):
                 max_return = max_return.max(axis=0)
             # If the price more than doubled, use a log scale
             if max_return >= 2:
-                axis.set_yscale("log", basey=2)
+                axis.set_yscale("log", base=2)
                 axis.set_ylabel("Cumulative return (log scale)")
             else:
                 self._y_format_at_least_two_decimal_places(axis)
@@ -276,7 +281,7 @@ class BaseTearsheet(object):
 
                 # If the price more than doubled, use a log scale
                 if max_return >= 2:
-                    axis.set_yscale("log", basey=2)
+                    axis.set_yscale("log", base=2)
                     axis.set_ylabel("Cumulative return (log scale)")
                 else:
                     self._y_format_at_least_two_decimal_places(axis)
