@@ -1,4 +1,4 @@
-# Copyright 2019 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2023 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Union, TextIO, overload
 import pandas as pd
 import matplotlib.pyplot as plt
 from matplotlib.font_manager import FontProperties
@@ -26,12 +27,18 @@ from .utils import with_baseline, get_cum_returns, get_drawdowns
 
 class ShortfallTearsheet(BaseTearsheet):
     """
-    Generate a tear sheet of performance stats and plots highlighting the
+    Create a tear sheet of performance stats and plots highlighting the
     shortfall between simulated or benchmark results and actual results.
 
     See Also
     --------
     ShortfallTearsheet.from_csvs : Create a shortfall tear sheet from CSVs.
+
+    Notes
+    -----
+    Usage Guide:
+
+    * Implementation Shortfall: https://qrok.it/dl/mc/shortfall
     """
 
     def __init__(self,
@@ -41,17 +48,65 @@ class ShortfallTearsheet(BaseTearsheet):
         super().__init__(*args, **kwargs)
         self.x_label, self.y_label = labels
 
+    @overload
     @classmethod
-    def from_csvs(cls, x_filepath_or_buffer, y_filepath_or_buffer,
-                  labels=("simulated", "actual"),
-                  start_date=None,
-                  end_date=None,
-                  largest_n=None,
-                  shift_x_positions=0,
-                  figsize=None, trim_outliers=None,
-                  how_to_aggregate=None,
-                  pdf_filename=None, riskfree=0,
-                  compound=True, rolling_sharpe_window=200):
+    def from_csvs(
+        cls,
+        x_filepath_or_buffer: Union[str, TextIO],
+        y_filepath_or_buffer: Union[str, TextIO],
+        labels: tuple[str, str] = ("simulated", "actual"),
+        start_date: str = None,
+        end_date: str = None,
+        largest_n: None = None,
+        shift_x_positions: int = 0,
+        figsize: tuple[int, int] = None,
+        trim_outliers: float = None,
+        how_to_aggregate: dict[str, str] = None,
+        pdf_filename: str = None,
+        riskfree: float = 0,
+        compound: bool = True,
+        rolling_sharpe_window: int = 200
+        ) -> None:
+        pass
+
+    @overload
+    @classmethod
+    def from_csvs(
+        cls,
+        x_filepath_or_buffer: Union[str, TextIO],
+        y_filepath_or_buffer: Union[str, TextIO],
+        labels: tuple[str, str] = ("simulated", "actual"),
+        start_date: str = None,
+        end_date: str = None,
+        largest_n: int = None,
+        shift_x_positions: int = 0,
+        figsize: tuple[int, int] = None,
+        trim_outliers: float = None,
+        how_to_aggregate: dict[str, str] = None,
+        pdf_filename: str = None,
+        riskfree: float = 0,
+        compound: bool = True,
+        rolling_sharpe_window: int = 200
+        ) -> pd.DataFrame:
+        pass
+
+    @classmethod
+    def from_csvs(
+        cls,
+        x_filepath_or_buffer,
+        y_filepath_or_buffer,
+        labels=("simulated", "actual"),
+        start_date=None,
+        end_date=None,
+        largest_n=None,
+        shift_x_positions=0,
+        figsize=None,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        pdf_filename=None,
+        riskfree=0,
+        compound=True,
+        rolling_sharpe_window=200):
         """
         Create a shortfall tear sheet comparing simulated results (or other benchmark results)
         with actual results.
@@ -119,9 +174,15 @@ class ShortfallTearsheet(BaseTearsheet):
         DataFrame or None
             DataFrame of largest shortfalls if largest_n is not None, otherwise None
 
+        Notes
+        -----
+        Usage Guide:
+
+        * Implementation Shortfall: https://qrok.it/dl/mc/shortfall
+
         Examples
         --------
-        >>> from moonshot import ShortfallTearsheet
+        >>> from moonchart import ShortfallTearsheet
         >>> ShortfallTearsheet.from_csvs("backtest.csv", "pnl.csv")
         """
 
@@ -149,8 +210,32 @@ class ShortfallTearsheet(BaseTearsheet):
         return t.create_full_tearsheet(x_perf, y_perf, largest_n=largest_n,
                                        shift_x_positions=shift_x_positions)
 
-    def create_full_tearsheet(self, x_performance, y_performance, largest_n=None,
-                              shift_x_positions=0):
+    @overload
+    def create_full_tearsheet(
+        self,
+        x_performance: DailyPerformance,
+        y_performance: DailyPerformance,
+        largest_n: None = None,
+        shift_x_positions: int = 0
+        ) -> None:
+        pass
+
+    @overload
+    def create_full_tearsheet(
+        self,
+        x_performance: DailyPerformance,
+        y_performance: DailyPerformance,
+        largest_n: int = None,
+        shift_x_positions: int = 0
+        ) -> pd.DataFrame:
+        pass
+
+    def create_full_tearsheet(
+        self,
+        x_performance,
+        y_performance,
+        largest_n=None,
+        shift_x_positions=0):
         """
         Create a shortfall tear sheet comparing simulated results (or other
         benchmark results) with actual results.
@@ -185,6 +270,12 @@ class ShortfallTearsheet(BaseTearsheet):
         See Also
         --------
         ShortfallTearsheet.from_csvs : Create a shortfall tear sheet from CSVs.
+
+        Notes
+        -----
+        Usage Guide:
+
+        * Implementation Shortfall: https://qrok.it/dl/mc/shortfall
         """
 
         y_agg_performance = AggregateDailyPerformance(y_performance)
@@ -262,7 +353,12 @@ class ShortfallTearsheet(BaseTearsheet):
 
         return largest_shortfalls
 
-    def create_largest_shortfalls_tearsheet(self, x_performance, y_performance, largest_n=5):
+    def create_largest_shortfalls_tearsheet(
+        self,
+        x_performance: DailyPerformance,
+        y_performance: DailyPerformance,
+        largest_n: int = 5
+        ) -> pd.DataFrame:
         """
         Create a "largest shortfalls" table highligting the dates and
         specific instruments or strategies (depending on whether the columns
@@ -412,7 +508,11 @@ class ShortfallTearsheet(BaseTearsheet):
         results.plot(ax=axis, title="Daily " + fig_title)
         axis.set_xlabel("")
 
-    def create_summary_tearsheet(self, x_performance, y_performance):
+    def create_summary_tearsheet(
+        self,
+        x_performance: DailyPerformance,
+        y_performance: DailyPerformance
+        ) -> None:
         """
         Create a tear sheet of summary shortfall stats in a table.
 
